import { Wikis, Chat, Scales, Flash } from "@carbon/icons-react";
import { Link } from "@components/Link";

export interface FeatureProps {
  title: string;
  description: string;
  href?: string;
  hrefCaption?: string;
  icon: "wikis" | "chat" | "scales" | "flash";
  className?: string;
}

export function Feature({
  title,
  description,
  icon,
  href,
  hrefCaption,
  className,
}: FeatureProps) {
  const ICON_SIZE = 24;
  const ICON_MAP: Record<typeof icon, React.ReactNode> = {
    wikis: <Wikis size={ICON_SIZE} />,
    chat: <Chat size={ICON_SIZE} />,
    scales: <Scales size={ICON_SIZE} />,
    flash: <Flash size={ICON_SIZE} />,
  };
  return (
    <div className={`fs-flex fs-flex-row ${className}`}>
      <div className="fs-size-12 fs-aspect-square fs-rounded-md fs-bg-red-500 fs-flex fs-justify-center fs-items-center fs-text-white">
        {ICON_MAP[icon]}
      </div>
      <div className="fs-grow fs-ml-4">
        <h5 className="fs-font-plex fs-text-lg fs-leading-6 fs-font-medium fs-text-grey-900">
          {title}
        </h5>
        <p className="fs-mt-2.5 fs-text-grey-500 fs-font-plex fs-text-base fs-leading-6 fs-font-normal xl:fs-text-grey-900">
          {description}{" "}
          {href && (
            <span className="fs-hidden xl:fs-inline-block">
              <Link to={href}>{hrefCaption || "Learn more"}</Link>
            </span>
          )}
        </p>
      </div>
    </div>
  );
}
