import clsx from "clsx";
import type { PropsWithChildren } from "react";

export interface GridProps {
  columns: 2 | 3 | 4 | 5 | 6;
  customResponsiveColumn?: string;
  customGap?: string;
}

export function Grid({
  columns = 2,
  customGap = "",
  customResponsiveColumn = "",
  children,
}: PropsWithChildren<GridProps>) {
  const GRID_MAPPING: Record<string, string> = {
    2: "fs-grid sm:fs-grid-cols-2",
    3: "fs-grid xl:fs-grid-cols-3",
    4: "fs-grid xl:fs-grid-cols-4",
    5: "fs-grid xl:fs-grid-cols-5",
    6: "fs-grid xl:fs-grid-cols-6",
  };
  const RESPONSIVE_MAPPING: Record<string, string> = {
    2: "",
    3: "sm:fs-grid-cols-2",
    4: "fs-grid-cols-2",
    5: "fs-grid-cols-2 sm:fs-grid-cols-3",
    6: "fs-grid-cols-2 sm:fs-grid-cols-4",
  };
  return (
    <div
      className={clsx(
        GRID_MAPPING[columns],
        customResponsiveColumn
          ? customResponsiveColumn
          : RESPONSIVE_MAPPING[columns],
        customGap || "fs-gap-8 sm:fs-gap-12",
      )}
    >
      {children}
    </div>
  );
}
