import { Link } from "@components/Link";
import { IMobileMenu } from "@interfaces/IHeader";
import clsx from "clsx";

export function MobileMenu({ isMobileOpen, data }: IMobileMenu) {
  return (
    <div
      className={clsx(
        "fs-absolute no-scrollbar fs-left-1/2 -fs-translate-x-1/2 container lg:fs-hidden fs-pt-10 fs-overflow-y-scroll fs-h-full fs-pb-48 fs-transition-opacity fs-ease-out fs-duration-500 fs-delay-300 fs-opacity-0",
        isMobileOpen
          ? "fs-opacity-100 fs-translate-y-0"
          : "fs-translate-y-[-9999px]",
      )}
    >
      <div className="fs-w-full fs-flex fs-flex-col md:fs-flex-row md:fs-flex-wrap fs-font-plex">
        {data.map((submenu, index) => (
          <div
            key={index}
            className="fs-w-full md:fs-w-1/3 lg:fs-w-1/5 md:fs-mt-0 fs-mb-16 md:fs-mb-8 lg:fs-mb-0"
          >
            {submenu.children && submenu.children.length > 0 ? (
              <h5 className="fs-w-fit fs-text-sm fs-leading-5 fs-font-semibold fs-text-grey-50">
                {submenu.title}
              </h5>
            ) : (
              <Link
                to={submenu.target}
                className="fs-w-fit fs-text-sm fs-leading-5 fs-font-semibold fs-text-grey-50"
              >
                {submenu.title}
              </Link>
            )}
            {submenu.children && submenu.children.length > 0 && (
              <ul>
                {submenu.children.map((child, index) => (
                  <li key={index} className="fs-w-fit fs-mt-5">
                    <Link
                      to={child.target}
                      className="fs-text-sm fs-leading-5 fs-font-normal fs-text-grey-400"
                    >
                      {child.title}
                    </Link>
                  </li>
                ))}
              </ul>
            )}
          </div>
        ))}
      </div>
    </div>
  );
}
