import { MouseEvent } from "react";
import { Maximize as MaximizeIcon } from "@carbon/icons-react";
import { OverlayTag } from "@components/OverlayTag";
import { IImage } from "@interfaces/IImage";
import clsx from "clsx";

type BaseProps = {
  onClick?: (e: MouseEvent<HTMLDivElement>) => void;
  className?: string;
  faded?: boolean;
  onLoad?: () => void;
  inSlider?: boolean;
  onFullscreen?: () => void;
  captionHtml?: string;
};

export type ImageProps = IImage & BaseProps;

export function Image({
  src,
  caption,
  alt,
  subCaption,
  onFullscreen,
  className = "",
  tag,
  onClick,
  faded = false,
  onLoad,
  inSlider,
  width,
  height,
  captionHtml,
}: ImageProps) {
  return src ? (
    <figure
      className={clsx(
        "fs-not-prose fs-table",
        inSlider && "fs-min-w-0 fs-flex-initial",
        className,
      )}
    >
      {/* Additional container to position Tag and button elements on top of image */}
      <div
        onClick={onClick}
        className={clsx(
          "fs-transition-opacity fs-relative",
          faded
            ? "fs-opacity-60 hover:fs-opacity-80 fs-cursor-pointer"
            : "fs-opacity-100",
          inSlider
            ? "fs-h-[212px] sm:fs-h-[300px] lg:fs-h-[487px]"
            : "fs-max-h-[212px] sm:fs-max-h-[300px] lg:fs-max-h-[487px]",
        )}
      >
        <img
          onLoad={onLoad}
          className={clsx(
            "fs-rounded-sm fs-h-full",
            inSlider ? "fs-max-w-none" : "fs-object-cover",
          )}
          src={src}
          alt={alt || caption}
          title={caption}
          width={width}
          height={height}
        />
        {tag && <OverlayTag text={tag} className="fs-absolute fs-bottom-5" />}
        {Boolean(onFullscreen) && (
          <button
            onClick={onFullscreen}
            className="fs-absolute fs-z-10 fs-size-6 fs-bg-white/50 hover:fs-bg-white fs-rounded fs-right-5 fs-bottom-5 fs-flex fs-items-center fs-justify-center"
            title="Maximize"
          >
            <MaximizeIcon />
          </button>
        )}
      </div>

      {(caption || subCaption) && (
        <figcaption className="fs-h-full fs-table-caption fs-caption-bottom fs-font-inter fs-text-xs fs-leading-[1.1rem] fs-font-normal ">
          <span className="fs-text-grey-900">
            {captionHtml ? (
              <span dangerouslySetInnerHTML={{ __html: captionHtml }}></span>
            ) : (
              <span>{caption}</span>
            )}{" "}
            <span className="fs-text-grey-400">{subCaption}</span>
          </span>
        </figcaption>
      )}
    </figure>
  ) : null;
}
