import { Logo } from "@components/Logo";
import { LinkOrContainer } from "./LinkOrContainer";
import clsx from "clsx";

export interface LogoResponsiveProps {
  href?: string;
  desktopLight?: boolean;
  mobileLight?: boolean;
  desktopMonotone?: boolean;
  mobileMonotone?: boolean;
  className?: string;
  desktopClasses?: string;
  mobileClasses?: string;
  organization?: "fchh" | "frbs";
}

export function LogoResponsive({
  href,
  desktopLight,
  mobileLight,
  desktopMonotone,
  mobileMonotone,
  className,
  desktopClasses,
  mobileClasses,
  organization = "fchh",
}: LogoResponsiveProps) {
  const containerClasses =
    "fs-block fs-w-auto lg:fs-w-36 lg:fs-h-auto fs-h-6 fs-z-10";

  return (
    <LinkOrContainer className={clsx(containerClasses, className)} href={href}>
      {/* Desktop viewports */}
      <Logo
        lightColor={desktopLight}
        monotone={desktopMonotone}
        className={clsx("fs-hidden lg:fs-block", desktopClasses)}
        organization={organization}
      />
      {/* Mobile viewports */}
      <Logo
        lightColor={mobileLight}
        monotone={mobileMonotone}
        className={clsx("fs-h-full fs-block lg:fs-hidden", mobileClasses)}
        organization={organization}
      />
    </LinkOrContainer>
  );
}
