import { useState, useEffect } from "react";
import { IToolbar, IToolbarItem } from "@interfaces/IHeader";
import { Link } from "@components/Link";
import { useMediaQuery } from "@hooks/useMediaQuery";
import clsx from "clsx";

export function Toolbar({
  isMobileOpen,
  className = "",
  items,
  extendedToolbarItems,
}: IToolbar) {
  const isMobileOrTabletSize = useMediaQuery("(max-width: 1024px)");
  const [shouldDisableFadingFx, setShouldDisableFadingFx] = useState(false);
  const [shouldFadeOthers, setShouldFadeOthers] = useState(false);

  useEffect(() => {
    setShouldDisableFadingFx(isMobileOrTabletSize);
  }, [isMobileOrTabletSize]);

  return items?.length ? (
    <div
      className={clsx(
        extendedToolbarItems
          ? "container fs-px-5"
          : "lg:fs-w-fit fs-px-9 fs-hidden lg:fs-block",
        isMobileOpen
          ? "fs-block fs-border-white !fs-bg-transparent"
          : "fs-border-black fs-hidden lg:fs-block",
        "sm:fs-border-x fs-border-y fs-transition-all fs-ease-in-out fs-duration-500 sm:fs-bg-white fs-select-none",
        className,
      )}
    >
      <div className="fs-w-full fs-flex fs-justify-center sm:fs-justify-between fs-items-center fs-py-3 sm:fs-py-5">
        <div
          className={clsx("fs-w-full", extendedToolbarItems && "lg:fs-w-auto")}
        >
          <ul
            className={clsx(
              "fs-w-full fs-flex fs-justify-between fs-uppercase sm:fs-normal-case fs-items-center",
              isMobileOpen ? "fs-text-white" : "fs-text-grey-900",
            )}
          >
            {items?.map((item, index) => (
              <ToolbarItem
                key={index}
                {...item}
                faded={shouldFadeOthers}
                onHover={(value) =>
                  !shouldDisableFadingFx && setShouldFadeOthers(value)
                }
                className={index !== 0 ? "sm:fs-ml-10" : ""}
              />
            ))}
          </ul>
        </div>
        {extendedToolbarItems && (
          <div className="fs-hidden lg:fs-block">
            <ul className="fs-flex fs-opacity-20">
              {extendedToolbarItems.map((item, index) => (
                <li
                  key={index}
                  className={`${
                    index !== extendedToolbarItems.length - 1
                      ? "fs-mr-6 xl:fs-mr-4"
                      : ""
                  } fs-cursor-pointer`}
                >
                  <Link to={item.href}>{item.icon}</Link>
                </li>
              ))}
            </ul>
          </div>
        )}
      </div>
    </div>
  ) : null;
}

function ToolbarItem({
  title,
  icon,
  href,
  onlyDesktop,
  className = "",
  faded,
  onHover,
}: IToolbarItem) {
  const classes =
    "fs-text-sm sm:fs-text-base fs-leading-5 sm:fs-leading-6 fs-font-semibold sm:fs-font-medium fs-tracking-wider sm:fs-tracking-normal fs-transition-all fs-ease-in fs-duration-100 lg:hover:fs-text-grey-900";
  return (
    <li
      onMouseEnter={() => onHover && onHover(true)}
      onMouseLeave={() => onHover && onHover(false)}
      className={clsx(
        classes,
        className,
        onlyDesktop && "fs-hidden lg:fs-block",
        faded ? "fs-text-grey-400" : "lg:fs-text-grey-900",
      )}
    >
      <Link
        to={href}
        className="fs-flex fs-flex-col sm:fs-flex-row fs-items-center"
      >
        {icon}
        <span>{title}</span>
      </Link>
    </li>
  );
}
