import { VerticalNewsCard } from "@components/VerticalNewsCard";
import { INewsCard, INews, Color } from "@interfaces/INews";
import { BaseSlider } from "./BaseSlider";

export interface VerticalNewsCardSliderBaseProps {
  title?: string;
  items: Array<INews | INewsCard>;
  fullBleed?: boolean;
  id?: string;
  className?: string;
}

type VerticalNewsCardSliderCustomColor =
  | {
      variant?: never;
      customBackgroundColor?: Color;
      textColor?: "dark" | "light";
    }
  | {
      variant: "light" | "dark";
      customBackgroundColor?: never;
      textColor?: never;
    };

export type VerticalNewsCardSliderProps = VerticalNewsCardSliderBaseProps &
  VerticalNewsCardSliderCustomColor;

export function VerticalNewsCardSlider({
  className = "",
  title,
  items,
  customBackgroundColor,
  textColor,
  fullBleed,
  id,
  variant,
}: VerticalNewsCardSliderProps) {
  return (
    <BaseSlider
      className={className}
      id={id}
      fullBleed={fullBleed}
      title={title}
      items={items}
    >
      {() => (
        <>
          {items?.map((item, index) =>
            variant ? (
              <VerticalNewsCard
                key={item.id || index}
                image={item.image}
                title={item.title}
                description={item.description}
                date={item.date}
                location={item.location}
                category={item.category}
                href={item.href}
                variant={variant}
                className="fs-ml-4 embla__slide"
              />
            ) : (
              <VerticalNewsCard
                key={item.id || index}
                image={item.image}
                title={item.title}
                description={item.description}
                date={item.date}
                location={item.location}
                category={item.category}
                href={item.href}
                customBackgroundColor={customBackgroundColor}
                textColor={textColor}
                className="fs-ml-4 embla__slide"
              />
            ),
          )}
        </>
      )}
    </BaseSlider>
  );
}
